AbstractCrudService<T> class abstract

Implementers

Constructors

AbstractCrudService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<List<T>>
createItem(T data) Future<void>
deleteItem(String uid) Future<void>
getAllItems() Future<List<T>>
getItemByUid(String uid) Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateItem(T data) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited