BaseModelGeneralRegistry class

Annotations
  • @Riverpod.new(keepAlive: true)

Constructors

BaseModelGeneralRegistry()

Properties

exampleRegistryMap Map<Type, Map<GeneralRegistryKey, dynamic>>
example
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Map<Type, Map<GeneralRegistryKey, dynamic>>
getFactory<T extends BaseModel>() BaseModelFactory<T>
getWidget<T extends BaseModel>(T item) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<T extends BaseModel>({BaseModelFactory<T>? factory, dynamic widget}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited