BaseModelRegistry class
- Annotations
-
- @Riverpod.new(keepAlive: true)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Map< Type, BaseModelFactory< BaseModel> > -
getFactory<
T extends BaseModel> () → BaseModelFactory< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T extends BaseModel> (BaseModelFactory< T> factory) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited