Reservation class abstract

Implemented types
Annotations
  • @freezed
  • @ReactiveFormAnnotation.new()
  • @FormGroupAnnotation.new<dynamic>()

Constructors

Reservation({required String uid, required String subjectUid, required String objectType, required String objectUid, @JsonKey.new(fromJson: timestampListToDateTimeList, toJson: dateTimeListToTimestampList) @FormArrayAnnotation.new<dynamic>() @Default.new([]) List<DateTime> reservedDateTimes, @FormControlAnnotation.new<dynamic>() @ReservationStateConverter() ReservationState? reservationState, @JsonKey.new(fromJson: timestampToDateTime, toJson: dateTimeToTimestamp) required DateTime createdAt, @JsonKey.new(fromJson: timestampToDateTime, toJson: dateTimeToTimestamp) required DateTime updatedAt, @FormArrayAnnotation.new<dynamic>() List<String>? filePaths})
const
factory
Reservation.defaultModel()
factory
Reservation.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ReservationCopyWith<Reservation>
no setterinherited
createdAt DateTime
no setterinherited
filePaths List<String>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
objectType String
no setterinherited
objectUid String
no setterinherited
reservationState ReservationState?
no setterinherited
reservedDateTimes List<DateTime>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectUid String
no setterinherited
uid String
no setterinherited
updatedAt DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited