ReservationForm class
Properties
-
containsCreatedAt
→ bool
-
no setter
-
containsFilePaths
→ bool
-
no setter
-
containsObjectType
→ bool
-
no setter
-
containsObjectUid
→ bool
-
no setter
-
containsReservationState
→ bool
-
no setter
-
containsReservedDateTimes
→ bool
-
no setter
-
containsSubjectUid
→ bool
-
no setter
-
containsUid
→ bool
-
no setter
-
containsUpdatedAt
→ bool
-
no setter
-
createdAtControl
→ FormControl<DateTime>
-
no setter
-
createdAtErrors
→ Map<String, Object>
-
no setter
-
createdAtFocus
→ void
-
no setter
-
currentForm
→ AbstractControl
-
no setter
-
filePathsControl
→ FormArray<String>?
-
no setter
-
filePathsControlControls
→ List<FormControl<String>?>
-
no setter
-
filePathsErrors
→ Map<String, Object>?
-
no setter
-
filePathsFocus
→ void
-
no setter
-
form
→ FormGroup
-
final
-
hasChanged
→ bool
-
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
initial
→ Map<String, Object?>?
-
finalinherited
-
model
→ Reservation
-
no setter
-
objectTypeControl
→ FormControl<String>
-
no setter
-
objectTypeErrors
→ Map<String, Object>
-
no setter
-
objectTypeFocus
→ void
-
no setter
-
objectUidControl
→ FormControl<String>
-
no setter
-
objectUidErrors
→ Map<String, Object>
-
no setter
-
objectUidFocus
→ void
-
no setter
-
path
→ String?
-
final
-
rawModel
→ dynamic
-
no setterinherited
-
reservationStateControl
→ FormControl<ReservationState>?
-
no setter
-
reservationStateErrors
→ Map<String, Object>?
-
no setter
-
reservationStateFocus
→ void
-
no setter
-
reservedDateTimesControl
→ FormArray<DateTime>
-
no setter
-
reservedDateTimesControlControls
→ List<FormControl<DateTime>>
-
no setter
-
reservedDateTimesErrors
→ Map<String, Object>
-
no setter
-
reservedDateTimesFocus
→ void
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
subjectUidControl
→ FormControl<String>
-
no setter
-
subjectUidErrors
→ Map<String, Object>
-
no setter
-
subjectUidFocus
→ void
-
no setter
-
uidControl
→ FormControl<String>
-
no setter
-
uidErrors
→ Map<String, Object>
-
no setter
-
uidFocus
→ void
-
no setter
-
updatedAtControl
→ FormControl<DateTime>
-
no setter
-
updatedAtErrors
→ Map<String, Object>
-
no setter
-
updatedAtFocus
→ void
-
no setter
Methods
-
addFilePathsItem(String value, {List<AsyncValidator>? asyncValidators, List<Validator>? validators, int? asyncValidatorsDebounceTime, bool? disabled, ValidatorsApplyMode validatorsApplyMode = ValidatorsApplyMode.merge})
→ void
-
-
addReservedDateTimesItem(DateTime value, {List<AsyncValidator>? asyncValidators, List<Validator>? validators, int? asyncValidatorsDebounceTime, bool? disabled, ValidatorsApplyMode validatorsApplyMode = ValidatorsApplyMode.merge})
→ void
-
-
createdAtControlPath()
→ String
-
-
createdAtSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
createdAtValuePatch(DateTime value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
createdAtValueReset(DateTime value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
createdAtValueUpdate(DateTime value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
equalsTo(Reservation? other)
→ bool
-
-
filePathsControlPath()
→ String
-
-
filePathsRemove({bool updateParent = true, bool emitEvent = true})
→ void
-
-
filePathsSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
filePathsValuePatch(List<String>? value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
filePathsValueReset(List<String>? value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
filePathsValueUpdate(List<String>? value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
objectTypeControlPath()
→ String
-
-
objectTypeSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
objectTypeValuePatch(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
objectTypeValueReset(String value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
objectTypeValueUpdate(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
objectUidControlPath()
→ String
-
-
objectUidSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
objectUidValuePatch(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
objectUidValueReset(String value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
objectUidValueUpdate(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
pathBuilder(String? pathItem)
→ String
-
-
reservationStateControlPath()
→ String
-
-
reservationStateRemove({bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservationStateSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservationStateValuePatch(ReservationState? value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservationStateValueReset(ReservationState? value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
reservationStateValueUpdate(ReservationState? value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservedDateTimesControlPath()
→ String
-
-
reservedDateTimesSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservedDateTimesValuePatch(List<DateTime> value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reservedDateTimesValueReset(List<DateTime> value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
reservedDateTimesValueUpdate(List<DateTime> value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
reset({Reservation? value, bool updateParent = true, bool emitEvent = true})
→ void
-
-
subjectUidControlPath()
→ String
-
-
subjectUidSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
subjectUidValuePatch(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
subjectUidValueReset(String value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
subjectUidValueUpdate(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
submit({required void onValid(Reservation model), void onNotValid()?})
→ void
-
-
toggleDisabled({bool updateParent = true, bool emitEvent = true})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
uidControlPath()
→ String
-
-
uidSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
uidValuePatch(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
uidValueReset(String value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
uidValueUpdate(String value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
updatedAtControlPath()
→ String
-
-
updatedAtSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
updatedAtValuePatch(DateTime value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
updatedAtValueReset(DateTime value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled})
→ void
-
-
updatedAtValueUpdate(DateTime value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
updateInitial(Map<String, Object?>? value, String? path)
→ void
-
inherited
-
updateValue(Reservation? value, {bool updateParent = true, bool emitEvent = true})
→ void
-
-
upsertValue(dynamic value, {bool updateParent = true, bool emitEvent = true})
→ void
-
inherited