ReservationStateForm class

Constructors

ReservationStateForm(FormGroup form, String? path)

Properties

containsCreatedAt bool
no setter
containsFilePaths bool
no setter
containsUid bool
no setter
containsUpdatedAt bool
no setter
createdAtControl → FormControl<DateTime>
no setter
createdAtErrors Map<String, Object>
no setter
createdAtFocus → void
no setter
currentForm → AbstractControl
no setter
filePathsControl → FormArray<String>?
no setter
filePathsControlControls List<FormControl<String>?>
no setter
filePathsErrors Map<String, Object>?
no setter
filePathsFocus → void
no setter
form → FormGroup
final
hashCode int
The hash code for this object.
no setterinherited
model ReservationState
no setter
path String?
final
rawModel → dynamic
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uidControl → FormControl<String>
no setter
uidErrors Map<String, Object>
no setter
uidFocus → void
no setter
updatedAtControl → FormControl<DateTime>
no setter
updatedAtErrors Map<String, Object>
no setter
updatedAtFocus → void
no setter

Methods

addFilePathsItem(String value, {List<AsyncValidator>? asyncValidators, List<Validator>? validators, int? asyncValidatorsDebounceTime, bool? disabled, ValidatorsApplyMode validatorsApplyMode = ValidatorsApplyMode.merge}) → void
createdAtControlPath() String
createdAtSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true}) → void
createdAtValuePatch(DateTime value, {bool updateParent = true, bool emitEvent = true}) → void
createdAtValueReset(DateTime value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled}) → void
createdAtValueUpdate(DateTime value, {bool updateParent = true, bool emitEvent = true}) → void
equalsTo(ReservationState? other) bool
filePathsControlPath() String
filePathsRemove({bool updateParent = true, bool emitEvent = true}) → void
filePathsSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true}) → void
filePathsValuePatch(List<String>? value, {bool updateParent = true, bool emitEvent = true}) → void
filePathsValueReset(List<String>? value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled}) → void
filePathsValueUpdate(List<String>? value, {bool updateParent = true, bool emitEvent = true}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathBuilder(String? pathItem) String
reset({ReservationState? value, bool updateParent = true, bool emitEvent = true}) → void
submit({required void onValid(ReservationState model), void onNotValid()?}) → void
toggleDisabled({bool updateParent = true, bool emitEvent = true}) → void
toString() String
A string representation of this object.
inherited
uidControlPath() String
uidSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true}) → void
uidValuePatch(String value, {bool updateParent = true, bool emitEvent = true}) → void
uidValueReset(String value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled}) → void
uidValueUpdate(String value, {bool updateParent = true, bool emitEvent = true}) → void
updatedAtControlPath() String
updatedAtSetDisabled(bool disabled, {bool updateParent = true, bool emitEvent = true}) → void
updatedAtValuePatch(DateTime value, {bool updateParent = true, bool emitEvent = true}) → void
updatedAtValueReset(DateTime value, {bool updateParent = true, bool emitEvent = true, bool removeFocus = false, bool? disabled}) → void
updatedAtValueUpdate(DateTime value, {bool updateParent = true, bool emitEvent = true}) → void
updateValue(ReservationState? value, {bool updateParent = true, bool emitEvent = true}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formElements(ReservationState? reservationState) → FormGroup