SelectedReservationsController<T extends BaseModel> class

Annotations
  • @riverpod

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<List<Reservation>>
getAll() Future<List<Reservation>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSelected(List<Reservation> selectedReservations) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited