TitleView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TitleView
Constructors
-
TitleView({Key? key, String titleTxt = "", Widget? titleWidget, double titleSize = 16, FontWeight titleFontWeight = FontWeight.w700, TextStyle? titleStyle, String subTxt = "", double subTxtSize = 12, Widget? bottomWidget, AnimationController? animationController, Animation<
double> ? animation, EdgeInsets padding = const EdgeInsets.only(left: 8, right: 8)}) -
const
Properties
-
animation
→ Animation<
double> ? -
final
- animationController → AnimationController?
-
final
- bottomWidget → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subTxt → String
-
final
- subTxtSize → double
-
final
- titleFontWeight → FontWeight
-
final
- titleSize → double
-
final
- titleStyle → TextStyle?
-
final
- titleTxt → String
-
final
- titleWidget → Widget?
-
final
Methods
-
createElement(
) → _StatefulHookConsumerElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConsumerState< TitleView> - Creates the mutable state for this widget at a given location in the tree.
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited