FilterSet class

Constructors

FilterSet(Set<ItemFilter> filters, {Set<ClientFilter>? clientFilters, Set<ItemOrder>? orderBy, int? limit})

Properties

clientFilters Set<ClientFilter>?
final
filters Set<ItemFilter>
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
final
orderBy Set<ItemOrder>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited