endBeforeDocument method
Sets the ending point for the query using a document snapshot.
Implementation
Query<T> endBeforeDocument(DocumentSnapshot documentSnapshot) {
state = state.endBeforeDocument(documentSnapshot);
return state;
}
Sets the ending point for the query using a document snapshot.
Query<T> endBeforeDocument(DocumentSnapshot documentSnapshot) {
state = state.endBeforeDocument(documentSnapshot);
return state;
}