startAfterDocument method
Sets the starting point for the query using a document snapshot.
Implementation
Query<T> startAfterDocument(DocumentSnapshot documentSnapshot) {
state = state.startAfterDocument(documentSnapshot);
return state;
}
Sets the starting point for the query using a document snapshot.
Query<T> startAfterDocument(DocumentSnapshot documentSnapshot) {
state = state.startAfterDocument(documentSnapshot);
return state;
}