FirestoreQueryBuilderRef<T> mixin

Properties

filterSet FilterSet?
The parameter filterSet of this provider.
no setter
firebaseFirestoreInstance → FirebaseFirestore?
The parameter firebaseFirestoreInstance of this provider.
no setter
fromJson → T Function(Map<String, dynamic> json)
The parameter fromJson of this provider.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited