CrudService<T extends BaseModel> class
- Implemented types
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addImagePaths(
T item, String imageUrl) → Future< void> -
build(
) → Future< List< T> > -
createItem(
T data) → Future< void> -
override
-
deleteFile(
String uid, String imageUrl) → Future< void> -
deleteItem(
String uid) → Future< void> -
override
-
getAllItems(
) → Future< List< T> > -
override
-
getImageUrlsFromStorage(
String uid) → Future< List< String> > -
getItemByUid(
String uid) → Future< T?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeImagePaths(
T item, String imageUrl) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateItem(
T data) → Future< void> -
override
-
uploadFile(
String uid, XFile file) → Future< String>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited