SearchService<T extends BaseModel> class
- Implemented types
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Future< List< T> > -
getAll(
) → Future< List< T> > -
override
-
getByEntranceYear(
String year) → Future< List< T> > -
getByName(
String name) → Future< List< T> > -
getByUid(
String uid) → Future< T?> -
override
-
getWithClientFilterSet(
{FilterSet? filterSet, String? orderBy, bool descending = false, int? limit}) → List< T> -
getWithFilterSet(
{FilterSet? filterSet, String? orderBy, bool descending = false, int? limit}) → Future< List< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited