ClientFilter class
Client-side filter This filter is applied to the data that is already fetched from the server. It is useful when you want to filter the data that is already in the client. For example, you can filter the data based on the user's input.
- Implemented types
Constructors
-
ClientFilter(String field, ClientFilterType clientFilterType, {Object? objectType, LinkedHashSet<
DateTime> ? isSameDayWith})
Properties
- clientFilterType → ClientFilterType
-
final
- field → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
isSameDayWith
→ LinkedHashSet<
DateTime> ? -
final
- objectType → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- test → bool Function(dynamic)
-
no setter
Methods
-
call(
List filteredItemList) → dynamic -
doFilter<
T extends BaseModel> (List< T> itemList) → List<T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override